==> velocity_1.6.2.orig.tar.gz: velocity-1.6.2/src/test/org/apache/velocity/test/issues/Velocity62TestCase.java <==
package org.apache.velocity.test.issues;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */

import org.apache.velocity.test.BaseEvalTestCase;
import org.apache.velocity.VelocityContext;
import org.apache.velocity.runtime.RuntimeConstants;

/**
 * This class tests VELOCITY-62.
 */
public class Velocity62TestCase extends BaseEvalTestCase
{
    public Velocity62TestCase(String name)
    {
       super(name);
    }

    public void setUp() throws Exception
    {
        super.setUp();
        engine.setProperty(RuntimeConstants.VM_CONTEXT_LOCALSCOPE, Boolean.TRUE);
        context.put("foo", "foo");
    }

    public void testNested()
    {
        String template = "#macro( outer )#set( $foo = 'bar' )#inner()#end"+
                          "#macro( inner )$foo#end"+
                          "#inner()#outer()#inner()";
        assertEvalEquals("foobarfoo", template);
    }

    public void testRecursive()
    {
        context.put("i", new Integer(1));
        String template = "#macro( recurse )"+
                            "$i"+
                            "#if( $i < 5 )"+
                              "#set( $i = $i + 1 )"+
                              "#recurse()"+
                            "#end"+
                          "#end"+
                          "#recurse()";
        assertEvalEquals("12345", template);
    }

}

==> velocity_1.7.orig.tar.gz: velocity-1.7/src/test/org/apache/velocity/test/issues/Velocity62TestCase.java <==
package org.apache.velocity.test.issues;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */

import org.apache.velocity.runtime.RuntimeConstants;
import org.apache.velocity.test.BaseTestCase;

/**
 * This class tests VELOCITY-62.
 */
public class Velocity62TestCase extends BaseTestCase
{
    public Velocity62TestCase(String name)
    {
       super(name);
    }

    public void setUp() throws Exception
    {
        super.setUp();
        engine.setProperty(RuntimeConstants.VM_CONTEXT_LOCALSCOPE, Boolean.TRUE);
        context.put("foo", "foo");
    }

    public void testNested()
    {
        String template = "#macro( outer )#set( $foo = 'bar' )#inner()#end"+
                          "#macro( inner )$foo#end"+
                          "#inner()#outer()#inner()";
        assertEvalEquals("foobarfoo", template);
    }

    public void testRecursive()
    {
        context.put("i", new Integer(1));
        String template = "#macro( recurse )"+
                            "$i"+
                            "#if( $i < 5 )"+
                              "#set( $i = $i + 1 )"+
                              "#recurse()"+
                            "#end"+
                          "#end"+
                          "#recurse()";
        assertEvalEquals("12345", template);
    }

}
